@@ -1,13 +1,12 @@
 import json
 from enum import Enum, auto
 
-from robot.api import logger  # type: ignore
-from robot.utils.robottime import timestr_to_secs  # type: ignore
-from robot.libraries.BuiltIn import BuiltIn  # type: ignore
 from robotlibcore import keyword  # type: ignore
 from typing import Optional, Dict, Any
 
+from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
+from ..utils.time_conversion import timestr_to_millisecs
 
 
 class MouseButton(Enum):
@@ -30,14 +29,7 @@ class SelectAttribute(Enum):
     index = auto()
 
 
-class Input:
-    def __init__(self, library):
-        self.library = library
-
-    @property
-    def playwright(self):
-        return self.library.playwright
-
+class Input(LibraryComponent):
     @keyword
     def type_text(
         self, selector: str, text: str, delay: str = "0 ms", clear: bool = True
@@ -54,14 +46,7 @@ class Input:
 
         See `Fill Text` for direct filling of the full text at once.
         """
-        with self.playwright.grpc_channel() as stub:
-            delay_ms = timestr_to_secs(delay) * 1000
-            response = stub.TypeText(
-                Request().typeText(
-                    selector=selector, text=text, delay=int(delay_ms), clear=clear
-                )
-            )
-            logger.info(response.log)
+        self._type_text(selector, text, delay, clear)
 
     @keyword
     def fill_text(self, selector: str, text: str):
@@ -77,9 +62,7 @@ class Input:
 
         See `Type Text` for emulating typing text character by character.
         """
-        with self.playwright.grpc_channel() as stub:
-            response = stub.FillText(Request().fillText(selector=selector, text=text))
-            logger.info(response.log)
+        self._fill_text(selector, text)
 
     @keyword
     def clear_text(self, selector: str):
@@ -89,8 +72,8 @@ class Input:
         See `Fill Text` for direct filling of the full text at once.
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.ClearText(Request().clearText(selector=selector))
-            logger.info(response.log)
+            response = stub.ClearText(Request().ClearText(selector=selector))
+            self.info(response.log)
 
     @keyword
     def type_secret(
@@ -103,11 +86,7 @@ class Input:
 
         See `Type Text` for details.
         """
-        previous_level = BuiltIn().set_log_level("NONE")
-        try:
-            self.type_text(selector, secret, delay, clear)
-        finally:
-            BuiltIn().set_log_level(previous_level)
+        self._type_text(selector, secret, delay, clear, log_response=False)
 
     @keyword
     def fill_secret(self, selector: str, secret: str):
@@ -118,11 +97,7 @@ class Input:
 
         See `Fill Text` for details.
         """
-        previous_level = BuiltIn().set_log_level("NONE")
-        try:
-            self.fill_text(selector, secret)
-        finally:
-            BuiltIn().set_log_level(previous_level)
+        self._fill_text(selector, secret, log_response=False)
 
     @keyword
     def press_keys(self, selector: str, *keys: str):
@@ -139,15 +114,15 @@ class Input:
         [https://github.com/microsoft/playwright/blob/master/docs/api.md#pagepressselector-key-options | Playwright docs for press.]
         """  # noqa
         with self.playwright.grpc_channel() as stub:
-            response = stub.Press(Request().press(selector=selector, key=keys))
-            logger.info(response.log)
+            response = stub.Press(Request().PressKeys(selector=selector, key=keys))
+            self.info(response.log)
 
     @keyword
     def click(self, selector: str):
         """Clicks the element found by ``selector``."""
         with self.playwright.grpc_channel() as stub:
-            response = stub.Click(Request().selector(selector=selector))
-            logger.info(response.log)
+            response = stub.Click(Request().ElementSelector(selector=selector))
+            self.info(response.log)
 
     @keyword
     def click_with_options(
@@ -181,18 +156,20 @@ class Input:
         with self.playwright.grpc_channel() as stub:
             options = {"button": button.name, "clickCount": click_count}
             if delay:
-                options["delay"] = int(timestr_to_secs(delay) * 1000)
+                options["delay"] = timestr_to_millisecs(delay)
             if position_x and position_y:
                 positions: Dict[str, object] = {"x": position_x, "y": position_y}
                 options["position"] = positions
             if modifiers:
                 options["modifiers"] = [m.name for m in modifiers]
             options_json = json.dumps(options)
-            logger.debug(f"Click Options are: {options_json}")
+            self.debug(f"Click Options are: {options_json}")
             response = stub.Click(
-                Request().selectorOptions(selector=selector, options=options_json)
+                Request().ElementSelectorOptions(
+                    selector=selector, options=options_json
+                )
             )
-            logger.info(response.log)
+            self.info(response.log)
 
     @keyword
     def focus(self, selector: str):
@@ -202,16 +179,18 @@ class Input:
         matching element appears in the DOM.
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.Focus(Request().selector(selector=selector))
-            logger.info(response.log)
+            response = stub.Focus(Request().ElementSelector(selector=selector))
+            self.info(response.log)
 
     @keyword
     def execute_javascript_on_page(self, script: str) -> Any:
+        """Executes given javascript on the page.
+        """
         with self.playwright.grpc_channel() as stub:
             response = stub.ExecuteJavascriptOnPage(
-                Request().jsExecution(script=script)
+                Request().JavascriptCode(script=script)
             )
-            logger.info(response.log)
+            self.info(response.log)
             return json.loads(response.result)
 
     @keyword
@@ -221,8 +200,8 @@ class Input:
         Does nothing if the element is already checked/selected.
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.CheckCheckbox(Request().selector(selector=selector))
-            logger.info(response.log)
+            response = stub.CheckCheckbox(Request().ElementSelector(selector=selector))
+            self.info(response.log)
 
     @keyword
     def uncheck_checkbox(self, selector: str):
@@ -231,8 +210,10 @@ class Input:
         Does nothing if the element is not checked/selected.
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.UncheckCheckbox(Request().selector(selector=selector))
-            logger.info(response.log)
+            response = stub.UncheckCheckbox(
+                Request().ElementSelector(selector=selector)
+            )
+            self.info(response.log)
 
     @keyword
     def select_options_by(self, attribute: SelectAttribute, selector: str, *values):
@@ -257,13 +238,37 @@ class Input:
             matchers = json.dumps([{"index": int(s)} for s in values])
         with self.playwright.grpc_channel() as stub:
             response = stub.SelectOption(
-                Request().selectOption(selector=selector, matcherJson=matchers)
+                Request().SelectElementSelector(selector=selector, matcherJson=matchers)
             )
-            logger.info(response.log)
+            self.info(response.log)
 
     @keyword
     def deselect_options(self, selector: str):
         """Deselects all options from select element found by ``selector``."""
         with self.playwright.grpc_channel() as stub:
-            response = stub.DeselectOption(Request().selector(selector=selector))
-            logger.info(response.log)
+            response = stub.DeselectOption(Request().ElementSelector(selector=selector))
+            self.info(response.log)
+
+    def _fill_text(self, selector: str, text: str, log_response: bool = True):
+        with self.playwright.grpc_channel() as stub:
+            response = stub.FillText(Request().FillText(selector=selector, text=text))
+            if log_response:
+                self.info(response.log)
+
+    def _type_text(
+        self,
+        selector: str,
+        text: str,
+        delay: str = "0 ms",
+        clear: bool = True,
+        log_response: bool = True,
+    ):
+        with self.playwright.grpc_channel() as stub:
+            delay_ms = timestr_to_millisecs(delay)
+            response = stub.TypeText(
+                Request().TypeText(
+                    selector=selector, text=text, delay=int(delay_ms), clear=clear
+                )
+            )
+            if log_response:
+                self.info(response.log)
