@@ -7,18 +7,19 @@ import time
 
 import grpc  # type: ignore
 from robot.api import logger  # type: ignore
-from robot.utils.robottime import timestr_to_secs  # type: ignore
 from robot.libraries.BuiltIn import BuiltIn  # type: ignore
 
 from Browser.generated.playwright_pb2 import Request
 import Browser.generated.playwright_pb2_grpc as playwright_pb2_grpc
+from Browser.utils.time_conversion import timestr_to_millisecs
 
 
 class Playwright:
     """A wrapper for communicating with nodejs Playwirght process."""
 
-    def __init__(self, timeout: str):
+    def __init__(self, timeout: str, enable_playwright_debug: bool):
         self.timeout = timeout
+        self.enable_playwright_debug = enable_playwright_debug
 
     @property
     def outputdir(self):
@@ -33,11 +34,13 @@ class Playwright:
     def start_playwright(self):
         workdir = os.path.join(os.path.dirname(os.path.abspath(__file__)), "wrapper")
         playwright_script = os.path.join(workdir, "index.js")
-        logfile = open(os.path.join(self.outputdir, "playwright-log.txt"), "w",)
+        logfile = open(os.path.join(self.outputdir, "playwright-log.txt"), "w")
         port = str(self.find_free_port())
         env = dict(os.environ)
         env["PORT"] = port
-        env["TIMEOUT"] = str(float(timestr_to_secs(self.timeout)) * 1000)
+        env["TIMEOUT"] = str(timestr_to_millisecs(self.timeout))
+        if self.enable_playwright_debug:
+            env["DEBUG"] = "pw:api"
         logger.info(f"Starting Browser process {playwright_script} using port {port}")
         self.port = port
         return Popen(
@@ -50,7 +53,7 @@ class Playwright:
         )
 
     def wait_until_server_up(self):
-        for i in range(30):
+        for i in range(50):
             with grpc.insecure_channel(f"localhost:{self.port}") as channel:
                 try:
                     stub = playwright_pb2_grpc.PlaywrightStub(channel)
@@ -78,8 +81,26 @@ class Playwright:
                 "Playwright process has been terminated with code {}".format(returncode)
             )
         channel = grpc.insecure_channel(f"localhost:{self.port}")
-        yield playwright_pb2_grpc.PlaywrightStub(channel)
-        channel.close()
+        try:
+            yield playwright_pb2_grpc.PlaywrightStub(channel)
+        except Exception as e:
+            raise AssertionError(self.get_reason(e))
+        finally:
+            channel.close()
+
+    def get_reason(self, err):
+        try:
+            metadata = err.trailing_metadata()
+            for element in metadata:
+                if element.key == "reason":
+                    return element.value
+        except AttributeError:
+            pass
+        try:
+            return err.details()
+        except AttributeError:
+            pass
+        return str(err)
 
     def close(self):
         logger.debug("Closing Playwright process")
